import { defineComponent, ref } from 'vue';
import {
  getGridDataPickerProps,
  useGridCellEditor,
  useNamespace,
} from '@ibiz-template/vue-util';

export const IBizGridPicker = defineComponent({
  name: 'IBizGridPicker',
  props: getGridDataPickerProps(),
  setup(props) {
    const ns = useNamespace('grid-picker');
    const multiple = props.controller.model.editorType === 'ADDRESSPICKUP';
    const provider = ref();
    ibiz.register.editor.get(props.controller.model).then(value => {
      provider.value = value;
    });
    const { isInfoMode, componentRef, onOperateChange, onChange } =
      useGridCellEditor(props.rowDataChange, props.rowSave, {
        isDelaySave: multiple,
      });

    return {
      ns,
      isInfoMode,
      componentRef,
      provider,
      onOperateChange,
      onChange,
    };
  },
  render(h) {
    return (
      <div
        ref='componentRef'
        class={`${this.ns.b()} ibiz-grid-editor`}
        onDblclick={evt => evt.stopPropagation()}
        onClick={evt => evt.stopPropagation()}
      >
        {this.provider &&
          h(this.provider.formEditor, {
            props: {
              ...this.$props,
              infoMode: this.isInfoMode,
            },
            on: {
              change: this.onChange,
              operate: this.onOperateChange,
            },
          })}
      </div>
    );
  },
});
